from __future__ import annotations
import sys
from importlib.machinery import ModuleSpec, PathFinder
from importlib.machinery import all_suffixes as module_suffixes
from importlib.util import spec_from_file_location
from itertools import chain
from pathlib import Path

MAPPING: dict[str, str] = {'accumulate': 'C:\\Accumulate_Stuff\\accumulate-python-client\\accumulate', 'dist': 'C:\\Accumulate_Stuff\\accumulate-python-client\\dist', 'docs': 'C:\\Accumulate_Stuff\\accumulate-python-client\\docs', 'examples': 'C:\\Accumulate_Stuff\\accumulate-python-client\\examples', 'htmlcov': 'C:\\Accumulate_Stuff\\accumulate-python-client\\htmlcov', 'site': 'C:\\Accumulate_Stuff\\accumulate-python-client\\site', 'tests': 'C:\\Accumulate_Stuff\\accumulate-python-client\\tests', 'venv': 'C:\\Accumulate_Stuff\\accumulate-python-client\\venv'}
NAMESPACES: dict[str, list[str]] = {'dist': ['C:\\Accumulate_Stuff\\accumulate-python-client\\dist'], 'docs': ['C:\\Accumulate_Stuff\\accumulate-python-client\\docs'], 'examples': ['C:\\Accumulate_Stuff\\accumulate-python-client\\examples'], 'htmlcov': ['C:\\Accumulate_Stuff\\accumulate-python-client\\htmlcov'], 'site': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site'], 'venv': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv'], 'examples.debug_archive': ['C:\\Accumulate_Stuff\\accumulate-python-client\\examples\\debug_archive'], 'site.api_reference': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\api_reference'], 'site.assets': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets'], 'site.changelog': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\changelog'], 'site.contributing': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\contributing'], 'site.examples': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\examples'], 'site.getting_started': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\getting_started'], 'site.search': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\search'], 'site.assets.images': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets\\images'], 'site.assets.javascripts': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets\\javascripts'], 'site.assets.stylesheets': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets\\stylesheets'], 'site.assets.javascripts.lunr': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets\\javascripts\\lunr'], 'site.assets.javascripts.workers': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets\\javascripts\\workers'], 'site.assets.javascripts.lunr.min': ['C:\\Accumulate_Stuff\\accumulate-python-client\\site\\assets\\javascripts\\lunr\\min'], 'tests.test_models': ['C:\\Accumulate_Stuff\\accumulate-python-client\\tests\\test_models'], 'tests.test_signing': ['C:\\Accumulate_Stuff\\accumulate-python-client\\tests\\test_signing'], 'tests.test_utils': ['C:\\Accumulate_Stuff\\accumulate-python-client\\tests\\test_utils'], 'venv.bitcoin': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\bitcoin'], 'venv.Include': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Include'], 'venv.Lib': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib'], 'venv.Scripts': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Scripts'], 'venv.Lib.site-packages': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages'], 'venv.Lib.site-packages.google': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\google'], 'venv.Lib.site-packages.jaraco': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jaraco'], 'venv.Lib.site-packages.mkdocstrings_handlers': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers'], 'venv.Lib.site-packages.rust': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust'], 'venv.Lib.site-packages.tiktoken_ext': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\tiktoken_ext'], 'venv.Lib.site-packages.babel.locale-data': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\babel\\locale-data'], 'venv.Lib.site-packages.coverage.htmlfiles': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\coverage\\htmlfiles'], 'venv.Lib.site-packages.cryptography.hazmat.bindings._rust': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\cryptography\\hazmat\\bindings\\_rust'], 'venv.Lib.site-packages.cryptography.hazmat.bindings._rust.openssl': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\cryptography\\hazmat\\bindings\\_rust\\openssl'], 'venv.Lib.site-packages.cytoolz.tests': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\cytoolz\\tests'], 'venv.Lib.site-packages.docutils.parsers.rst.include': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\parsers\\rst\\include'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.big-black': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\big-black'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.big-white': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\big-white'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.default': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\default'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.medium-black': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\medium-black'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.medium-white': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\medium-white'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.small-black': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\small-black'], 'venv.Lib.site-packages.docutils.writers.s5_html.themes.small-white': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\docutils\\writers\\s5_html\\themes\\small-white'], 'venv.Lib.site-packages.eth_utils.__json': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\eth_utils\\__json'], 'venv.Lib.site-packages.google._upb': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\google\\_upb'], 'venv.Lib.site-packages.h11.tests.data': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\h11\\tests\\data'], 'venv.Lib.site-packages.id._internal': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\id\\_internal'], 'venv.Lib.site-packages.jsonschema.benchmarks.issue232': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema\\benchmarks\\issue232'], 'venv.Lib.site-packages.jsonschema_specifications.schemas': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft201909': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft201909'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft202012': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft202012'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft3': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft3'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft4': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft4'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft6': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft6'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft7': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft7'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft201909.vocabularies': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft201909\\vocabularies'], 'venv.Lib.site-packages.jsonschema_specifications.schemas.draft202012.vocabularies': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\jsonschema_specifications\\schemas\\draft202012\\vocabularies'], 'venv.Lib.site-packages.material.templates.assets': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets'], 'venv.Lib.site-packages.material.templates.fragments': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\fragments'], 'venv.Lib.site-packages.material.templates.partials': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\partials'], 'venv.Lib.site-packages.material.templates.assets.images': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets\\images'], 'venv.Lib.site-packages.material.templates.assets.javascripts': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets\\javascripts'], 'venv.Lib.site-packages.material.templates.assets.stylesheets': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets\\stylesheets'], 'venv.Lib.site-packages.material.templates.assets.javascripts.lunr': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets\\javascripts\\lunr'], 'venv.Lib.site-packages.material.templates.assets.javascripts.workers': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets\\javascripts\\workers'], 'venv.Lib.site-packages.material.templates.assets.javascripts.lunr.min': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\assets\\javascripts\\lunr\\min'], 'venv.Lib.site-packages.material.templates.fragments.tags': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\fragments\\tags'], 'venv.Lib.site-packages.material.templates.fragments.tags.default': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\fragments\\tags\\default'], 'venv.Lib.site-packages.material.templates.partials.integrations': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\partials\\integrations'], 'venv.Lib.site-packages.material.templates.partials.javascripts': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\partials\\javascripts'], 'venv.Lib.site-packages.material.templates.partials.languages': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\partials\\languages'], 'venv.Lib.site-packages.material.templates.partials.integrations.analytics': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\material\\templates\\partials\\integrations\\analytics'], 'venv.Lib.site-packages.mkdocs.templates': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\templates'], 'venv.Lib.site-packages.mkdocs.contrib.search.lunr-language': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\contrib\\search\\lunr-language'], 'venv.Lib.site-packages.mkdocs.contrib.search.templates': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\contrib\\search\\templates'], 'venv.Lib.site-packages.mkdocs.contrib.search.templates.search': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\contrib\\search\\templates\\search'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.css': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\css'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.img': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\img'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.js': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\js'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.webfonts': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\webfonts'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.de': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\de'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.es': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\es'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.fa': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\fa'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.fr': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\fr'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.id': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\id'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.it': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\it'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.ja': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\ja'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.nb': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\nb'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.nl': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\nl'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.nn': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\nn'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.pl': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\pl'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.pt_BR': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\pt_BR'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.ru': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\ru'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.tr': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\tr'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.uk': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\uk'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.zh_CN': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\zh_CN'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.zh_TW': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\zh_TW'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.de.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\de\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.es.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\es\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.fa.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\fa\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.fr.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\fr\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.id.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\id\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.it.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\it\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.ja.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\ja\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.nb.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\nb\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.nl.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\nl\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.nn.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\nn\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.pl.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\pl\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.pt_BR.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\pt_BR\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.ru.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\ru\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.tr.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\tr\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.uk.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\uk\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.zh_CN.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\zh_CN\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.mkdocs.locales.zh_TW.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\mkdocs\\locales\\zh_TW\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.css': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\css'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.img': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\img'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.js': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\js'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.css.fonts': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\css\\fonts'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.de': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\de'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.es': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\es'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.fa': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\fa'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.fr': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\fr'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.id': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\id'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.it': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\it'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.ja': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\ja'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.nl': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\nl'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.pl': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\pl'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.pt_BR': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\pt_BR'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.ru': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\ru'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.tr': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\tr'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.uk': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\uk'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.zh_CN': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\zh_CN'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.zh_TW': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\zh_TW'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.de.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\de\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.es.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\es\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.fa.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\fa\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.fr.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\fr\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.id.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\id\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.it.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\it\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.ja.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\ja\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.nl.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\nl\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.pl.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\pl\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.pt_BR.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\pt_BR\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.ru.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\ru\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.tr.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\tr\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.uk.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\uk\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.zh_CN.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\zh_CN\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocs.themes.readthedocs.locales.zh_TW.LC_MESSAGES': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocs\\themes\\readthedocs\\locales\\zh_TW\\LC_MESSAGES'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.readthedocs': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\readthedocs'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material.docstring': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\docstring'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material.languages': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\languages'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material.summary': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\summary'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material._base': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\_base'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material._base.docstring': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\_base\\docstring'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material._base.languages': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\_base\\languages'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.material._base.summary': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\material\\_base\\summary'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.readthedocs.docstring': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\readthedocs\\docstring'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.readthedocs.languages': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\readthedocs\\languages'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.readthedocs._base': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\readthedocs\\_base'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.readthedocs._base.docstring': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\readthedocs\\_base\\docstring'], 'venv.Lib.site-packages.mkdocstrings_handlers.python.templates.readthedocs._base.languages': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\mkdocstrings_handlers\\python\\templates\\readthedocs\\_base\\languages'], 'venv.Lib.site-packages.rust.cryptography-cffi': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust\\cryptography-cffi'], 'venv.Lib.site-packages.rust.cryptography-keepalive': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust\\cryptography-keepalive'], 'venv.Lib.site-packages.rust.cryptography-key-parsing': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust\\cryptography-key-parsing'], 'venv.Lib.site-packages.rust.cryptography-openssl': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust\\cryptography-openssl'], 'venv.Lib.site-packages.rust.cryptography-x509': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust\\cryptography-x509'], 'venv.Lib.site-packages.rust.cryptography-x509-verification': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\rust\\cryptography-x509-verification'], 'venv.Lib.site-packages.toolz.tests': ['C:\\Accumulate_Stuff\\accumulate-python-client\\venv\\Lib\\site-packages\\toolz\\tests']}
PATH_PLACEHOLDER = '__editable__.accumulate_python_client-0.1.1.finder' + ".__path_hook__"


class _EditableFinder:  # MetaPathFinder
    @classmethod
    def find_spec(cls, fullname: str, path=None, target=None) -> ModuleSpec | None:  # type: ignore
        # Top-level packages and modules (we know these exist in the FS)
        if fullname in MAPPING:
            pkg_path = MAPPING[fullname]
            return cls._find_spec(fullname, Path(pkg_path))

        # Handle immediate children modules (required for namespaces to work)
        # To avoid problems with case sensitivity in the file system we delegate
        # to the importlib.machinery implementation.
        parent, _, child = fullname.rpartition(".")
        if parent and parent in MAPPING:
            return PathFinder.find_spec(fullname, path=[MAPPING[parent]])

        # Other levels of nesting should be handled automatically by importlib
        # using the parent path.
        return None

    @classmethod
    def _find_spec(cls, fullname: str, candidate_path: Path) -> ModuleSpec | None:
        init = candidate_path / "__init__.py"
        candidates = (candidate_path.with_suffix(x) for x in module_suffixes())
        for candidate in chain([init], candidates):
            if candidate.exists():
                return spec_from_file_location(fullname, candidate)
        return None


class _EditableNamespaceFinder:  # PathEntryFinder
    @classmethod
    def _path_hook(cls, path) -> type[_EditableNamespaceFinder]:
        if path == PATH_PLACEHOLDER:
            return cls
        raise ImportError

    @classmethod
    def _paths(cls, fullname: str) -> list[str]:
        paths = NAMESPACES[fullname]
        if not paths and fullname in MAPPING:
            paths = [MAPPING[fullname]]
        # Always add placeholder, for 2 reasons:
        # 1. __path__ cannot be empty for the spec to be considered namespace.
        # 2. In the case of nested namespaces, we need to force
        #    import machinery to query _EditableNamespaceFinder again.
        return [*paths, PATH_PLACEHOLDER]

    @classmethod
    def find_spec(cls, fullname: str, target=None) -> ModuleSpec | None:  # type: ignore
        if fullname in NAMESPACES:
            spec = ModuleSpec(fullname, None, is_package=True)
            spec.submodule_search_locations = cls._paths(fullname)
            return spec
        return None

    @classmethod
    def find_module(cls, _fullname) -> None:
        return None


def install():
    if not any(finder == _EditableFinder for finder in sys.meta_path):
        sys.meta_path.append(_EditableFinder)

    if not NAMESPACES:
        return

    if not any(hook == _EditableNamespaceFinder._path_hook for hook in sys.path_hooks):
        # PathEntryFinder is needed to create NamespaceSpec without private APIS
        sys.path_hooks.append(_EditableNamespaceFinder._path_hook)
    if PATH_PLACEHOLDER not in sys.path:
        sys.path.append(PATH_PLACEHOLDER)  # Used just to trigger the path hook
